==> v8.3.zip: ru_twords_ru_tw/bible/kt/righthand.md <==
# правая рука

## Определение:

Переносное значение словосочетания “правая рука” означает “почётное место справа” например, от царя или какого-либо важного человека.

* Правая рука является символом власти, силы и могущества.
* В Библии об Иисусе сказано, что Он сидит “по правую руку” от Бога Отца, поскольку Он является главой верующих (Церкви). Как правитель, Он управляет Своим творением.
* Когда человек возлагал правую руку на чью-то голову при благословении, этим самым он оказывал особое почтение благословляемому (как, например, Израиль, благословивший Ефрема, сына Иосифа).
* Быть правой рукой кого-то — значит быть тем, чей труд особенно полезен и важен для того человека.

## Варианты перевода:

* Словосочетание “правая рука” может буквально означать правую руку человека. Например, римские солдаты вложили посох в правую руку Иисуса, чтобы издеваться над Ним. В этом случае при переводе нужно использовать слово, означающее человеческую конечность (правую руку).
* При использовании словосочетания в переносном значении нужно учитывать возможность его иносказательного использования. Если в целевом языке это словосочетание можно использовать только в прямом значении, следует найти другое слово, означающее позицию власти.
* Выражение “по правую руку от...” может быть переведено как “с правой стороны от...”, “на почётном месте рядом с...” или “в положении силы и почёта”.
* Словосочетание “правая рука” можно перевести так: “обладающий полномочиями”, “пользующийся властью” или “обладающий силой”.
* Образное выражение “Его правая рука и Его могучая мышца”, использованные, чтобы подчеркнуть Божью силу и Его великое могущество, может быть переведено так: “Его удивительная сила и могущество”. (См.: [parallelism](rc://*/ta/man/translate/figs-parallelism))
* Выражение “их правая рука — это ложь” можно перевести так: “их самая почётная вещь испорчена ложью”, “место их почести испорчено обманом” или “они используют ложь, чтобы сделать себя значимыми”.

(См. также: [обвинять](../other/accuse.md), [зло](../kt/evil.md), [честь](../kt/honor.md), [могущественный](../other/mighty.md), [наказывать](../other/punish.md), [бунтарь](../other/rebel.md))

## Ссылки на библейский текст:

* [Деян. 2:32-33](rc://*/tn/help/act/02/32)
* [Кол. 3:1-4](rc://*/tn/help/col/03/01)
* [Гал. 2:9-10](rc://*/tn/help/gal/02/09)
* [Быт. 48:14-16](rc://*/tn/help/gen/48/14)
* [Евр. 10:11-14](rc://*/tn/help/heb/10/11)
* [Плач 2:3-4](rc://*/tn/help/lam/02/03)
* [Мф. 25:31-33](rc://*/tn/help/mat/25/31)
* [Мф. 26:62-64](rc://*/tn/help/mat/26/62)
* [Пс. 44:3-4](rc://*/tn/help/psa/044/003)
* [Откр. 2:1-2](rc://*/tn/help/rev/02/01)

## Данные о слове:

* Номера Стронга: H3225, H3231, H3233, G1188

==> v9.2.zip: ru_twords_ru_tw/bible/kt/righthand.md <==
# правая рука

## Определение:

 Переносное значение словосочетания “правая рука” означает “почётное место справа” например, от царя или какого-либо важного человека.
* Правая рука является символом власти, силы и могущества.
* В Библии об Иисусе сказано, что Он сидит “по правую руку” от Бога Отца, поскольку Он является главой верующих (Церкви). Как правитель, Он управляет Своим творением.
* Когда человек возлагал правую руку на чью-то голову при благословении, этим самым он оказывал особое почтение благословляемому (как, например, Израиль, благословивший Ефрема, сына Иосифа).
* Быть правой рукой кого-то — значит быть тем, чей труд особенно полезен и важен для того человека.

## Варианты перевода:

* Словосочетание “правая рука” может буквально означать правую руку человека. Например, римские солдаты вложили посох в правую руку Иисуса, чтобы издеваться над Ним. В этом случае при переводе нужно использовать слово, означающее человеческую конечность (правую руку).
* При использовании словосочетания в переносном значении нужно учитывать возможность его иносказательного использования. Если в целевом языке это словосочетание можно использовать только в прямом значении, следует найти другое слово, означающее позицию власти. 
*  Выражение “по правую руку от...” может быть переведено как “с правой стороны от...”, “на почётном месте рядом с...” или “в положении силы и почёта”.
* Словосочетание “правая рука” можно перевести так: “обладающий полномочиями”, “пользующийся властью” или “обладающий силой”.
* Образное выражение “Его правая рука и Его могучая мышца”, использованные, чтобы подчеркнуть Божью силу и Его великое могущество, может быть переведено так: “Его удивительная сила и могущество”. (См.: [parallelism](rc://ru/ta/man/translate/figs-parallelism))
* Выражение “их правая рука — это ложь” можно перевести так: “их самая почётная вещь испорчена ложью”, “место их почести испорчено обманом” или “они используют ложь, чтобы сделать себя значимыми”.

(См. также: [обвинять](../other/accuse.md), [зло](../kt/evil.md), [честь](../kt/honor.md), [могущественный](../other/mighty.md), [наказывать](../other/punish.md), [бунтарь](../other/rebel.md))

## Ссылки на библейский текст:

* [Деян. 2:32-33](rc://ru/tn/help/act/02/32)
* [Кол. 3:1-4](rc://ru/tn/help/col/03/01)
* [Гал. 2:9-10](rc://ru/tn/help/gal/02/09)
* [Быт. 48:14-16](rc://ru/tn/help/gen/48/14)
* [Евр. 10:11-14](rc://ru/tn/help/heb/10/11)
* [Плач 2:3-4](rc://ru/tn/help/lam/02/03)
* [Мф. 25:31-33](rc://ru/tn/help/mat/25/31)
* [Мф. 26:62-64](rc://ru/tn/help/mat/26/62)
* [Пс. 44:3-4](rc://ru/tn/help/psa/044/003)
* [Откр. 2:1-2](rc://ru/tn/help/rev/02/01)

## Данные о слове:

* Номера Стронга: H3225, H3231, H3233, G1188
